#!/bin/sh
# updatedb.sh - create database of path/files for
#               use with locate.sh.
#
# $Id: updatedb.sh,v 1.2 2002/03/17 02:44:36 jmurff Exp unknown $
# $Author: jmurff $
#
# $Log: updatedb.sh,v $
# Revision 1.2  2002/03/17 02:44:36  jmurff
# Moved locate.conf to /var/log.
#
# Revision 1.1  2002/03/17 00:13:20  jmurff
# Initial revision
#
#
#======================================
ldir_name=locatedb_dir
locate_conf="/var/log/locate.conf"
myname=`basename $0`

lpath="/home/root/$ldir_name"    # Main RAM Card Default

echo " "

# select output file via command option
while getopts rcs option
do
  case "$option"
  in
     r)
       lpath="/home/root/$ldir_name"    # Main RAM Card
       echo "$myname :: Using internal RAM for DB Storage."
       ;; 
	
     c)
       lpath="/mnt/cf/$ldir_name"       # CF Card
       echo "$myname :: Using CF Card for DB storage."
       ;; 

     s)
       lpath="/mnt/card/$ldir_name"     # SD/MMC Card
       echo "$myname :: Using SD card for DB Storage."
       ;; 

     \?)
       echo "Usage: $myname  [-rcsh]"
       echo "	-r = store DB on internal RAM."
       echo "	-c = store DB on CF Card."
       echo "	-s = store DB on SD Card."
       echo " "
       exit 1
       ;;

  esac
done

if [ ! -d $lpath ]; then
  echo "$myname :: Making directory for Locate Database."
  echo "$myname :: --> $lpath"
  mkdir $lpath
  if [ $? -ne 0 ]; then
     echo "$myname :: Error creating $lpath"
     echo " "
     exit 1
  fi
fi

locate_db="$lpath/locate.db"
if [ -e $locate_db ]; then
  echo "$myname :: Removing old Locate Database."
  echo "$myname :: --> $locate_db"
  rm -rf $locate_db
  if [ $? -ne 0 ]; then
     echo "$myname :: Error removing $locate_db"
     echo " "
     exit 1
  fi
fi

# Create Database for Locate
echo "$myname :: Creating new Locate Database"
echo "$myname :: --> $locate_db"

# Busybox find is really brain dead...
# Find works but gives error sometimes on /procs...
find / -print > $locate_db 2>/dev/null

# If you have a good find use this ::
# find / -path '/proc' -prune -o -print > $locate_db 2>/dev/null
#if [ $? -ne 0 ]; then
#     echo "$myname :: Error creating $locate_db"
#     echo " "
#     exit 1
#fi

# Make file needed for locate.
if [ -e $locate_conf ]; then
  echo "$myname :: Removing old locate config file."
  echo "$myname :; --> $locate_conf"
  rm -rf $locate_conf
  if [ $? -ne 0 ]; then
     echo "$myname :: Error removing $locate_conf"
     echo " "
     exit 1
  fi
fi

echo locate_db=$locate_db > $locate_conf
echo "$myname :: Created config file ($locate_conf)."
echo "$myname :: Done."
echo " "
exit 0
